@@ -1,4 +1,5 @@
 # Copyright 2014 - Mirantis, Inc.
+# Copyright 2015 - StackStorm, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -17,12 +18,20 @@ from mistralclient.tests.unit import base
 
 
 class BaseClientV2Test(base.BaseClientTest):
+
+    TEST_URL = 'http://mistral.example.com'
+
     def setUp(self):
         super(BaseClientV2Test, self).setUp()
 
         self._client = client.Client(project_name="test",
-                                     mistral_url="test")
+                                     mistral_url=self.TEST_URL)
         self.workbooks = self._client.workbooks
         self.executions = self._client.executions
         self.tasks = self._client.tasks
         self.workflows = self._client.workflows
+        self.environments = self._client.environments
+        self.action_executions = self._client.action_executions
+        self.actions = self._client.actions
+        self.services = self._client.services
+        self.members = self._client.members
